##
##  go2rtc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_go2rtc_base  1.9.6
%define       V_go2rtc_snap  20241029

#   package information
Name:         go2rtc
Summary:      Media Streaming Server
URL:          https://github.com/AlexxIT/go2rtc
Vendor:       aler9
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Multimedia
License:      MIT
Version:      %{V_go2rtc_base}.%{V_go2rtc_snap}
Release:      20241029

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/go2rtc/go2rtc-%{V_go2rtc_snap}.tar.xz
Source1:      go2rtc.yaml
Source2:      rc.go2rtc

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101, ffmpeg

%description
    Go2RTC is the ultimate camera streaming application with support
    RTSP, WebRTC, HomeKit, FFmpeg, RTMP, etc.

%track
    prog go2rtc:base = {
        version   = %{V_go2rtc_base}
        url       = https://github.com/AlexxIT/go2rtc/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }
    prog go2rtc:snap = {
        version   = %{V_go2rtc_snap}
        url       = http://download.openpkg.org/components/versioned/go2rtc/
        regex     = go2rtc-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n go2rtc

%build
    #   build program
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/AlexxIT/go2rtc
    go build -v -o go2rtc .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/go2rtc \
        $RPM_BUILD_ROOT%{l_prefix}/var/go2rtc/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/go2rtc/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/AlexxIT/go2rtc/go2rtc \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install configuration files
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE go2rtc.yaml} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/go2rtc/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.go2rtc} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/go2rtc/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/go2rtc/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} go2rtc status 2>/dev/null`
    [ ".$go2rtc_active" = .yes ] && %{l_rc} go2rtc restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} go2rtc stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/go2rtc/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/go2rtc/run/*  >/dev/null 2>&1 || true
    exit 0

